"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.analyzeVueComponentFromTemplate = void 0;
const type_analyzer_1 = require("@previewjs/type-analyzer");
const path_1 = __importDefault(require("path"));
const typescript_1 = __importDefault(require("typescript"));
function analyzeVueComponentFromTemplate(typescriptAnalyzer, getTypeAnalyzer, filePath) {
    // This virtual file exists thanks to transformReader().
    const tsFilePath = `${filePath}.ts`;
    const name = path_1.default.basename(filePath, path_1.default.extname(filePath));
    const program = typescriptAnalyzer.analyze([tsFilePath]);
    const typeAnalyzer = getTypeAnalyzer(program);
    const sourceFile = typeAnalyzer.sourceFile(tsFilePath);
    for (const statement of sourceFile.statements) {
        if (typescript_1.default.isTypeAliasDeclaration(statement) &&
            statement.name.text === "PJS_Props") {
            const type = typeAnalyzer.checker.getTypeAtLocation(statement);
            const defineComponentProps = typeAnalyzer.resolveType(type);
            return {
                name,
                propsType: defineComponentProps.type,
                providedArgs: new Set(),
                types: defineComponentProps.collected,
            };
        }
    }
    return {
        name,
        propsType: type_analyzer_1.UNKNOWN_TYPE,
        providedArgs: new Set(),
        types: {},
    };
}
exports.analyzeVueComponentFromTemplate = analyzeVueComponentFromTemplate;
